@@ -40,24 +40,10 @@ func New() *cobra.Command {
 		flag.App(),
 		flag.AppConfig(),
 		flag.Region(),
-		flag.Int{
-			Name:        "vm-cpus",
-			Description: "How many CPUs to give the new machine",
-			Aliases:     []string{"cpus"},
-		},
 		flag.String{
 			Name:        "machine",
 			Description: "Run the console in the existing machine with the specified ID",
 		},
-		flag.Int{
-			Name:        "vm-memory",
-			Description: "How much memory (in MB) to give the new machine",
-			Aliases:     []string{"memory"},
-		},
-		flag.String{
-			Name:        "vm-size",
-			Description: "Use a preset size for the new machine",
-		},
 		flag.Bool{
 			Name:        "select",
 			Shorthand:   "s",
@@ -70,6 +56,7 @@ func New() *cobra.Command {
 			Description: "Unix username to connect as",
 			Default:     ssh.DefaultSshUsername,
 		},
+		flag.VMSizeFlags,
 	)
 
 	return cmd
@@ -236,8 +223,9 @@ func makeEphemeralConsoleMachine(ctx context.Context, app *api.AppCompact, appCo
 
 	input := &machine.EphemeralInput{
 		LaunchInput: api.LaunchMachineInput{
-			Config: machConfig,
-			Region: config.FromContext(ctx).Region,
+			Config:           machConfig,
+			Region:           config.FromContext(ctx).Region,
+			HostDedicationID: appConfig.HostDedicationID,
 		},
 		What: "to run the console",
 	}
@@ -252,6 +240,10 @@ func determineEphemeralConsoleMachineGuest(ctx context.Context) (*api.MachineGue
 		}
 	}
 
+	if cpuKind := flag.GetString(ctx, "vm-cpukind"); cpuKind != "" {
+		desiredGuest.CPUKind = cpuKind
+	}
+
 	if flag.IsSpecified(ctx, "vm-cpus") {
 		cpus := flag.GetInt(ctx, "vm-cpus")
 		var maxCPUs int
