@@ -66,6 +66,7 @@ func stdArgsSSH(cmd *cobra.Command) {
 			Description: "Unix username to connect as",
 			Default:     DefaultSshUsername,
 		},
+		flag.ProcessGroup(),
 	)
 }
 
@@ -229,12 +230,27 @@ func addrForMachines(ctx context.Context, app *api.AppCompact, console bool) (ad
 		return "", fmt.Errorf("app %s has no started VMs", app.Name)
 	}
 
-	if err != nil {
-		return "", err
+	if region := flag.GetRegion(ctx); region != "" {
+		machines = lo.Filter(machines, func(m *api.Machine, _ int) bool {
+			return m.Region == region
+		})
+		if len(machines) < 1 {
+			return "", fmt.Errorf("app %s has no VMs in region %s", app.Name, region)
+		}
+	}
+
+	if group := flag.GetProcessGroup(ctx); group != "" {
+		machines = lo.Filter(machines, func(m *api.Machine, _ int) bool {
+			return m.ProcessGroup() == group
+		})
+		if len(machines) < 1 {
+			return "", fmt.Errorf("app %s has no VMs in process group %s", app.Name, group)
+		}
 	}
 
 	var namesWithRegion []string
 	var selectedMachine *api.Machine
+	multipleGroups := len(lo.UniqBy(machines, func(m *api.Machine) string { return m.ProcessGroup() })) > 1
 
 	for _, machine := range machines {
 		nameWithRegion := fmt.Sprintf("%s: %s %s %s", machine.Region, machine.ID, machine.PrivateIP, machine.Name)
@@ -254,6 +270,9 @@ func addrForMachines(ctx context.Context, app *api.AppCompact, console bool) (ad
 			nameWithRegion += fmt.Sprintf(" (%s)", role)
 		}
 
+		if multipleGroups {
+			nameWithRegion += fmt.Sprintf(" (%s)", machine.ProcessGroup())
+		}
 		namesWithRegion = append(namesWithRegion, nameWithRegion)
 	}
 
