@@ -10,7 +10,7 @@ import (
 	"github.com/spf13/cobra"
 
 	"github.com/superfly/flyctl/api"
-	"github.com/superfly/flyctl/client"
+	"github.com/superfly/flyctl/flaps"
 
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/volumes/snapshots"
@@ -42,14 +42,14 @@ func New() *cobra.Command {
 	return cmd
 }
 
-func printVolume(w io.Writer, vol *api.Volume) error {
+func printVolume(w io.Writer, vol *api.Volume, appName string) error {
 	var buf bytes.Buffer
 
 	fmt.Fprintf(&buf, "%10s: %s\n", "ID", vol.ID)
 	fmt.Fprintf(&buf, "%10s: %s\n", "Name", vol.Name)
-	fmt.Fprintf(&buf, "%10s: %s\n", "App", vol.App.Name)
+	fmt.Fprintf(&buf, "%10s: %s\n", "App", appName)
 	fmt.Fprintf(&buf, "%10s: %s\n", "Region", vol.Region)
-	fmt.Fprintf(&buf, "%10s: %s\n", "Zone", vol.Host.ID)
+	fmt.Fprintf(&buf, "%10s: %s\n", "Zone", vol.Zone)
 	fmt.Fprintf(&buf, "%10s: %d\n", "Size GB", vol.SizeGb)
 	fmt.Fprintf(&buf, "%10s: %t\n", "Encrypted", vol.Encrypted)
 	fmt.Fprintf(&buf, "%10s: %s\n", "Created at", vol.CreatedAt.Format(time.RFC822))
@@ -59,15 +59,15 @@ func printVolume(w io.Writer, vol *api.Volume) error {
 	return err
 }
 
-func countVolumesMatchingName(ctx context.Context, appName string, volumeName string) (int32, error) {
+func countVolumesMatchingName(ctx context.Context, volumeName string) (int32, error) {
 	var (
 		volumes []api.Volume
 		err     error
 
-		client = client.FromContext(ctx).API()
+		flapsClient = flaps.FromContext(ctx)
 	)
 
-	if volumes, err = client.GetVolumes(ctx, appName); err != nil {
+	if volumes, err = flapsClient.GetVolumes(ctx); err != nil {
 		return 0, err
 	}
 
